.. author: Pavel Korshunov <pavel.korshunov@idiap.ch>
.. date: Wed Apr 27 14:58:21 CEST 2016

===========================
Python API for bob.pad.base
===========================

Summary
=======

Databases
---------

.. autosummary::

    bob.pad.base.pipelines.Database
    bob.pad.base.database.FileListPadDatabase


Score Functions
---------------

.. autosummary::

    bob.pad.base.error_utils.split_csv_pad
    bob.pad.base.error_utils.split_csv_pad_per_pai
    bob.pad.base.error_utils.calc_threshold
    bob.pad.base.error_utils.apcer_threshold
    bob.pad.base.error_utils.apcer_bpcer

Details
-------

.. automodule:: bob.pad.base
.. automodule:: bob.pad.base.pipelines
.. automodule:: bob.pad.base.database
.. automodule:: bob.pad.base.error_utils

.. include:: links.rst
